@@ -1,17 +1,7 @@
-/*
-  * Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-  *
-  * Licensed under the Apache License, Version 2.0 (the "License").
-  * You may not use this file except in compliance with the License.
-  * A copy of the License is located at
-  *
-  *  http://aws.amazon.com/apache2.0
-  *
-  * or in the "license" file accompanying this file. This file is distributed
-  * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-  * express or implied. See the License for the specific language governing
-  * permissions and limitations under the License.
-  */
+/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 
@@ -49,6 +39,8 @@ namespace Aws
         extern AWS_CORE_API const char X_AMZ_EXPIRES_HEADER[];
         extern AWS_CORE_API const char CONTENT_MD5_HEADER[];
         extern AWS_CORE_API const char API_VERSION_HEADER[];
+        extern AWS_CORE_API const char SDK_INVOCATION_ID_HEADER[];
+        extern AWS_CORE_API const char SDK_REQUEST_HEADER[];
         extern AWS_CORE_API const char CHUNKED_VALUE[];
 
         class HttpRequest;
