@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/s3/S3_EXPORTS.h>
@@ -95,50 +85,234 @@ namespace Model
 
 
     /**
-     * <p>The name of the source bucket and key name of the source object, separated by
-     * a slash (/). Must be URL-encoded.</p>
+     * <p>Specifies the source object for the copy operation. You specify the value in
+     * one of two formats, depending on whether you want to access the source object
+     * through an <a
+     * href="https://docs.aws.amazon.com/AmazonS3/latest/dev/access-points.html">access
+     * point</a>:</p> <ul> <li> <p>For objects not accessed through an access point,
+     * specify the name of the source bucket and key of the source object, separated by
+     * a slash (/). For example, to copy the object <code>reports/january.pdf</code>
+     * from the bucket <code>awsexamplebucket</code>, use
+     * <code>awsexamplebucket/reports/january.pdf</code>. The value must be URL
+     * encoded.</p> </li> <li> <p>For objects accessed through access points, specify
+     * the Amazon Resource Name (ARN) of the object as accessed through the access
+     * point, in the format
+     * <code>arn:aws:s3:&lt;Region&gt;:&lt;account-id&gt;:accesspoint/&lt;access-point-name&gt;/object/&lt;key&gt;</code>.
+     * For example, to copy the object <code>reports/january.pdf</code> through the
+     * access point <code>my-access-point</code> owned by account
+     * <code>123456789012</code> in Region <code>us-west-2</code>, use the URL encoding
+     * of
+     * <code>arn:aws:s3:us-west-2:123456789012:accesspoint/my-access-point/object/reports/january.pdf</code>.
+     * The value must be URL encoded.</p>  <p>Amazon S3 supports copy operations
+     * using access points only when the source and destination buckets are in the same
+     * AWS Region.</p>  </li> </ul> <p>To copy a specific version of an object,
+     * append <code>?versionId=&lt;version-id&gt;</code> to the value (for example,
+     * <code>awsexamplebucket/reports/january.pdf?versionId=QUpfdndhfd8438MNFDN93jdnJFkdmqnh893</code>).
+     * If you don't specify a version ID, Amazon S3 copies the latest version of the
+     * source object.</p>
      */
     inline const Aws::String& GetCopySource() const{ return m_copySource; }
 
     /**
-     * <p>The name of the source bucket and key name of the source object, separated by
-     * a slash (/). Must be URL-encoded.</p>
+     * <p>Specifies the source object for the copy operation. You specify the value in
+     * one of two formats, depending on whether you want to access the source object
+     * through an <a
+     * href="https://docs.aws.amazon.com/AmazonS3/latest/dev/access-points.html">access
+     * point</a>:</p> <ul> <li> <p>For objects not accessed through an access point,
+     * specify the name of the source bucket and key of the source object, separated by
+     * a slash (/). For example, to copy the object <code>reports/january.pdf</code>
+     * from the bucket <code>awsexamplebucket</code>, use
+     * <code>awsexamplebucket/reports/january.pdf</code>. The value must be URL
+     * encoded.</p> </li> <li> <p>For objects accessed through access points, specify
+     * the Amazon Resource Name (ARN) of the object as accessed through the access
+     * point, in the format
+     * <code>arn:aws:s3:&lt;Region&gt;:&lt;account-id&gt;:accesspoint/&lt;access-point-name&gt;/object/&lt;key&gt;</code>.
+     * For example, to copy the object <code>reports/january.pdf</code> through the
+     * access point <code>my-access-point</code> owned by account
+     * <code>123456789012</code> in Region <code>us-west-2</code>, use the URL encoding
+     * of
+     * <code>arn:aws:s3:us-west-2:123456789012:accesspoint/my-access-point/object/reports/january.pdf</code>.
+     * The value must be URL encoded.</p>  <p>Amazon S3 supports copy operations
+     * using access points only when the source and destination buckets are in the same
+     * AWS Region.</p>  </li> </ul> <p>To copy a specific version of an object,
+     * append <code>?versionId=&lt;version-id&gt;</code> to the value (for example,
+     * <code>awsexamplebucket/reports/january.pdf?versionId=QUpfdndhfd8438MNFDN93jdnJFkdmqnh893</code>).
+     * If you don't specify a version ID, Amazon S3 copies the latest version of the
+     * source object.</p>
      */
     inline bool CopySourceHasBeenSet() const { return m_copySourceHasBeenSet; }
 
     /**
-     * <p>The name of the source bucket and key name of the source object, separated by
-     * a slash (/). Must be URL-encoded.</p>
+     * <p>Specifies the source object for the copy operation. You specify the value in
+     * one of two formats, depending on whether you want to access the source object
+     * through an <a
+     * href="https://docs.aws.amazon.com/AmazonS3/latest/dev/access-points.html">access
+     * point</a>:</p> <ul> <li> <p>For objects not accessed through an access point,
+     * specify the name of the source bucket and key of the source object, separated by
+     * a slash (/). For example, to copy the object <code>reports/january.pdf</code>
+     * from the bucket <code>awsexamplebucket</code>, use
+     * <code>awsexamplebucket/reports/january.pdf</code>. The value must be URL
+     * encoded.</p> </li> <li> <p>For objects accessed through access points, specify
+     * the Amazon Resource Name (ARN) of the object as accessed through the access
+     * point, in the format
+     * <code>arn:aws:s3:&lt;Region&gt;:&lt;account-id&gt;:accesspoint/&lt;access-point-name&gt;/object/&lt;key&gt;</code>.
+     * For example, to copy the object <code>reports/january.pdf</code> through the
+     * access point <code>my-access-point</code> owned by account
+     * <code>123456789012</code> in Region <code>us-west-2</code>, use the URL encoding
+     * of
+     * <code>arn:aws:s3:us-west-2:123456789012:accesspoint/my-access-point/object/reports/january.pdf</code>.
+     * The value must be URL encoded.</p>  <p>Amazon S3 supports copy operations
+     * using access points only when the source and destination buckets are in the same
+     * AWS Region.</p>  </li> </ul> <p>To copy a specific version of an object,
+     * append <code>?versionId=&lt;version-id&gt;</code> to the value (for example,
+     * <code>awsexamplebucket/reports/january.pdf?versionId=QUpfdndhfd8438MNFDN93jdnJFkdmqnh893</code>).
+     * If you don't specify a version ID, Amazon S3 copies the latest version of the
+     * source object.</p>
      */
     inline void SetCopySource(const Aws::String& value) { m_copySourceHasBeenSet = true; m_copySource = value; }
 
     /**
-     * <p>The name of the source bucket and key name of the source object, separated by
-     * a slash (/). Must be URL-encoded.</p>
+     * <p>Specifies the source object for the copy operation. You specify the value in
+     * one of two formats, depending on whether you want to access the source object
+     * through an <a
+     * href="https://docs.aws.amazon.com/AmazonS3/latest/dev/access-points.html">access
+     * point</a>:</p> <ul> <li> <p>For objects not accessed through an access point,
+     * specify the name of the source bucket and key of the source object, separated by
+     * a slash (/). For example, to copy the object <code>reports/january.pdf</code>
+     * from the bucket <code>awsexamplebucket</code>, use
+     * <code>awsexamplebucket/reports/january.pdf</code>. The value must be URL
+     * encoded.</p> </li> <li> <p>For objects accessed through access points, specify
+     * the Amazon Resource Name (ARN) of the object as accessed through the access
+     * point, in the format
+     * <code>arn:aws:s3:&lt;Region&gt;:&lt;account-id&gt;:accesspoint/&lt;access-point-name&gt;/object/&lt;key&gt;</code>.
+     * For example, to copy the object <code>reports/january.pdf</code> through the
+     * access point <code>my-access-point</code> owned by account
+     * <code>123456789012</code> in Region <code>us-west-2</code>, use the URL encoding
+     * of
+     * <code>arn:aws:s3:us-west-2:123456789012:accesspoint/my-access-point/object/reports/january.pdf</code>.
+     * The value must be URL encoded.</p>  <p>Amazon S3 supports copy operations
+     * using access points only when the source and destination buckets are in the same
+     * AWS Region.</p>  </li> </ul> <p>To copy a specific version of an object,
+     * append <code>?versionId=&lt;version-id&gt;</code> to the value (for example,
+     * <code>awsexamplebucket/reports/january.pdf?versionId=QUpfdndhfd8438MNFDN93jdnJFkdmqnh893</code>).
+     * If you don't specify a version ID, Amazon S3 copies the latest version of the
+     * source object.</p>
      */
     inline void SetCopySource(Aws::String&& value) { m_copySourceHasBeenSet = true; m_copySource = std::move(value); }
 
     /**
-     * <p>The name of the source bucket and key name of the source object, separated by
-     * a slash (/). Must be URL-encoded.</p>
+     * <p>Specifies the source object for the copy operation. You specify the value in
+     * one of two formats, depending on whether you want to access the source object
+     * through an <a
+     * href="https://docs.aws.amazon.com/AmazonS3/latest/dev/access-points.html">access
+     * point</a>:</p> <ul> <li> <p>For objects not accessed through an access point,
+     * specify the name of the source bucket and key of the source object, separated by
+     * a slash (/). For example, to copy the object <code>reports/january.pdf</code>
+     * from the bucket <code>awsexamplebucket</code>, use
+     * <code>awsexamplebucket/reports/january.pdf</code>. The value must be URL
+     * encoded.</p> </li> <li> <p>For objects accessed through access points, specify
+     * the Amazon Resource Name (ARN) of the object as accessed through the access
+     * point, in the format
+     * <code>arn:aws:s3:&lt;Region&gt;:&lt;account-id&gt;:accesspoint/&lt;access-point-name&gt;/object/&lt;key&gt;</code>.
+     * For example, to copy the object <code>reports/january.pdf</code> through the
+     * access point <code>my-access-point</code> owned by account
+     * <code>123456789012</code> in Region <code>us-west-2</code>, use the URL encoding
+     * of
+     * <code>arn:aws:s3:us-west-2:123456789012:accesspoint/my-access-point/object/reports/january.pdf</code>.
+     * The value must be URL encoded.</p>  <p>Amazon S3 supports copy operations
+     * using access points only when the source and destination buckets are in the same
+     * AWS Region.</p>  </li> </ul> <p>To copy a specific version of an object,
+     * append <code>?versionId=&lt;version-id&gt;</code> to the value (for example,
+     * <code>awsexamplebucket/reports/january.pdf?versionId=QUpfdndhfd8438MNFDN93jdnJFkdmqnh893</code>).
+     * If you don't specify a version ID, Amazon S3 copies the latest version of the
+     * source object.</p>
      */
     inline void SetCopySource(const char* value) { m_copySourceHasBeenSet = true; m_copySource.assign(value); }
 
     /**
-     * <p>The name of the source bucket and key name of the source object, separated by
-     * a slash (/). Must be URL-encoded.</p>
+     * <p>Specifies the source object for the copy operation. You specify the value in
+     * one of two formats, depending on whether you want to access the source object
+     * through an <a
+     * href="https://docs.aws.amazon.com/AmazonS3/latest/dev/access-points.html">access
+     * point</a>:</p> <ul> <li> <p>For objects not accessed through an access point,
+     * specify the name of the source bucket and key of the source object, separated by
+     * a slash (/). For example, to copy the object <code>reports/january.pdf</code>
+     * from the bucket <code>awsexamplebucket</code>, use
+     * <code>awsexamplebucket/reports/january.pdf</code>. The value must be URL
+     * encoded.</p> </li> <li> <p>For objects accessed through access points, specify
+     * the Amazon Resource Name (ARN) of the object as accessed through the access
+     * point, in the format
+     * <code>arn:aws:s3:&lt;Region&gt;:&lt;account-id&gt;:accesspoint/&lt;access-point-name&gt;/object/&lt;key&gt;</code>.
+     * For example, to copy the object <code>reports/january.pdf</code> through the
+     * access point <code>my-access-point</code> owned by account
+     * <code>123456789012</code> in Region <code>us-west-2</code>, use the URL encoding
+     * of
+     * <code>arn:aws:s3:us-west-2:123456789012:accesspoint/my-access-point/object/reports/january.pdf</code>.
+     * The value must be URL encoded.</p>  <p>Amazon S3 supports copy operations
+     * using access points only when the source and destination buckets are in the same
+     * AWS Region.</p>  </li> </ul> <p>To copy a specific version of an object,
+     * append <code>?versionId=&lt;version-id&gt;</code> to the value (for example,
+     * <code>awsexamplebucket/reports/january.pdf?versionId=QUpfdndhfd8438MNFDN93jdnJFkdmqnh893</code>).
+     * If you don't specify a version ID, Amazon S3 copies the latest version of the
+     * source object.</p>
      */
     inline UploadPartCopyRequest& WithCopySource(const Aws::String& value) { SetCopySource(value); return *this;}
 
     /**
-     * <p>The name of the source bucket and key name of the source object, separated by
-     * a slash (/). Must be URL-encoded.</p>
+     * <p>Specifies the source object for the copy operation. You specify the value in
+     * one of two formats, depending on whether you want to access the source object
+     * through an <a
+     * href="https://docs.aws.amazon.com/AmazonS3/latest/dev/access-points.html">access
+     * point</a>:</p> <ul> <li> <p>For objects not accessed through an access point,
+     * specify the name of the source bucket and key of the source object, separated by
+     * a slash (/). For example, to copy the object <code>reports/january.pdf</code>
+     * from the bucket <code>awsexamplebucket</code>, use
+     * <code>awsexamplebucket/reports/january.pdf</code>. The value must be URL
+     * encoded.</p> </li> <li> <p>For objects accessed through access points, specify
+     * the Amazon Resource Name (ARN) of the object as accessed through the access
+     * point, in the format
+     * <code>arn:aws:s3:&lt;Region&gt;:&lt;account-id&gt;:accesspoint/&lt;access-point-name&gt;/object/&lt;key&gt;</code>.
+     * For example, to copy the object <code>reports/january.pdf</code> through the
+     * access point <code>my-access-point</code> owned by account
+     * <code>123456789012</code> in Region <code>us-west-2</code>, use the URL encoding
+     * of
+     * <code>arn:aws:s3:us-west-2:123456789012:accesspoint/my-access-point/object/reports/january.pdf</code>.
+     * The value must be URL encoded.</p>  <p>Amazon S3 supports copy operations
+     * using access points only when the source and destination buckets are in the same
+     * AWS Region.</p>  </li> </ul> <p>To copy a specific version of an object,
+     * append <code>?versionId=&lt;version-id&gt;</code> to the value (for example,
+     * <code>awsexamplebucket/reports/january.pdf?versionId=QUpfdndhfd8438MNFDN93jdnJFkdmqnh893</code>).
+     * If you don't specify a version ID, Amazon S3 copies the latest version of the
+     * source object.</p>
      */
     inline UploadPartCopyRequest& WithCopySource(Aws::String&& value) { SetCopySource(std::move(value)); return *this;}
 
     /**
-     * <p>The name of the source bucket and key name of the source object, separated by
-     * a slash (/). Must be URL-encoded.</p>
+     * <p>Specifies the source object for the copy operation. You specify the value in
+     * one of two formats, depending on whether you want to access the source object
+     * through an <a
+     * href="https://docs.aws.amazon.com/AmazonS3/latest/dev/access-points.html">access
+     * point</a>:</p> <ul> <li> <p>For objects not accessed through an access point,
+     * specify the name of the source bucket and key of the source object, separated by
+     * a slash (/). For example, to copy the object <code>reports/january.pdf</code>
+     * from the bucket <code>awsexamplebucket</code>, use
+     * <code>awsexamplebucket/reports/january.pdf</code>. The value must be URL
+     * encoded.</p> </li> <li> <p>For objects accessed through access points, specify
+     * the Amazon Resource Name (ARN) of the object as accessed through the access
+     * point, in the format
+     * <code>arn:aws:s3:&lt;Region&gt;:&lt;account-id&gt;:accesspoint/&lt;access-point-name&gt;/object/&lt;key&gt;</code>.
+     * For example, to copy the object <code>reports/january.pdf</code> through the
+     * access point <code>my-access-point</code> owned by account
+     * <code>123456789012</code> in Region <code>us-west-2</code>, use the URL encoding
+     * of
+     * <code>arn:aws:s3:us-west-2:123456789012:accesspoint/my-access-point/object/reports/january.pdf</code>.
+     * The value must be URL encoded.</p>  <p>Amazon S3 supports copy operations
+     * using access points only when the source and destination buckets are in the same
+     * AWS Region.</p>  </li> </ul> <p>To copy a specific version of an object,
+     * append <code>?versionId=&lt;version-id&gt;</code> to the value (for example,
+     * <code>awsexamplebucket/reports/january.pdf?versionId=QUpfdndhfd8438MNFDN93jdnJFkdmqnh893</code>).
+     * If you don't specify a version ID, Amazon S3 copies the latest version of the
+     * source object.</p>
      */
     inline UploadPartCopyRequest& WithCopySource(const char* value) { SetCopySource(value); return *this;}
 
@@ -529,7 +703,7 @@ namespace Model
      * encrypting data. This value is used to store the object and then it is
      * discarded; Amazon S3 does not store the encryption key. The key must be
      * appropriate for use with the algorithm specified in the
-     * <code>x-amz-server-side​-encryption​-customer-algorithm</code> header. This must
+     * <code>x-amz-server-side-encryption-customer-algorithm</code> header. This must
      * be the same encryption key specified in the initiate multipart upload
      * request.</p>
      */
@@ -540,7 +714,7 @@ namespace Model
      * encrypting data. This value is used to store the object and then it is
      * discarded; Amazon S3 does not store the encryption key. The key must be
      * appropriate for use with the algorithm specified in the
-     * <code>x-amz-server-side​-encryption​-customer-algorithm</code> header. This must
+     * <code>x-amz-server-side-encryption-customer-algorithm</code> header. This must
      * be the same encryption key specified in the initiate multipart upload
      * request.</p>
      */
@@ -551,7 +725,7 @@ namespace Model
      * encrypting data. This value is used to store the object and then it is
      * discarded; Amazon S3 does not store the encryption key. The key must be
      * appropriate for use with the algorithm specified in the
-     * <code>x-amz-server-side​-encryption​-customer-algorithm</code> header. This must
+     * <code>x-amz-server-side-encryption-customer-algorithm</code> header. This must
      * be the same encryption key specified in the initiate multipart upload
      * request.</p>
      */
@@ -562,7 +736,7 @@ namespace Model
      * encrypting data. This value is used to store the object and then it is
      * discarded; Amazon S3 does not store the encryption key. The key must be
      * appropriate for use with the algorithm specified in the
-     * <code>x-amz-server-side​-encryption​-customer-algorithm</code> header. This must
+     * <code>x-amz-server-side-encryption-customer-algorithm</code> header. This must
      * be the same encryption key specified in the initiate multipart upload
      * request.</p>
      */
@@ -573,7 +747,7 @@ namespace Model
      * encrypting data. This value is used to store the object and then it is
      * discarded; Amazon S3 does not store the encryption key. The key must be
      * appropriate for use with the algorithm specified in the
-     * <code>x-amz-server-side​-encryption​-customer-algorithm</code> header. This must
+     * <code>x-amz-server-side-encryption-customer-algorithm</code> header. This must
      * be the same encryption key specified in the initiate multipart upload
      * request.</p>
      */
@@ -584,7 +758,7 @@ namespace Model
      * encrypting data. This value is used to store the object and then it is
      * discarded; Amazon S3 does not store the encryption key. The key must be
      * appropriate for use with the algorithm specified in the
-     * <code>x-amz-server-side​-encryption​-customer-algorithm</code> header. This must
+     * <code>x-amz-server-side-encryption-customer-algorithm</code> header. This must
      * be the same encryption key specified in the initiate multipart upload
      * request.</p>
      */
@@ -595,7 +769,7 @@ namespace Model
      * encrypting data. This value is used to store the object and then it is
      * discarded; Amazon S3 does not store the encryption key. The key must be
      * appropriate for use with the algorithm specified in the
-     * <code>x-amz-server-side​-encryption​-customer-algorithm</code> header. This must
+     * <code>x-amz-server-side-encryption-customer-algorithm</code> header. This must
      * be the same encryption key specified in the initiate multipart upload
      * request.</p>
      */
@@ -606,7 +780,7 @@ namespace Model
      * encrypting data. This value is used to store the object and then it is
      * discarded; Amazon S3 does not store the encryption key. The key must be
      * appropriate for use with the algorithm specified in the
-     * <code>x-amz-server-side​-encryption​-customer-algorithm</code> header. This must
+     * <code>x-amz-server-side-encryption-customer-algorithm</code> header. This must
      * be the same encryption key specified in the initiate multipart upload
      * request.</p>
      */
@@ -852,6 +1026,120 @@ namespace Model
     inline UploadPartCopyRequest& WithRequestPayer(RequestPayer&& value) { SetRequestPayer(std::move(value)); return *this;}
 
 
+    /**
+     * <p>The account id of the expected destination bucket owner. If the destination
+     * bucket is owned by a different account, the request will fail with an HTTP
+     * <code>403 (Access Denied)</code> error.</p>
+     */
+    inline const Aws::String& GetExpectedBucketOwner() const{ return m_expectedBucketOwner; }
+
+    /**
+     * <p>The account id of the expected destination bucket owner. If the destination
+     * bucket is owned by a different account, the request will fail with an HTTP
+     * <code>403 (Access Denied)</code> error.</p>
+     */
+    inline bool ExpectedBucketOwnerHasBeenSet() const { return m_expectedBucketOwnerHasBeenSet; }
+
+    /**
+     * <p>The account id of the expected destination bucket owner. If the destination
+     * bucket is owned by a different account, the request will fail with an HTTP
+     * <code>403 (Access Denied)</code> error.</p>
+     */
+    inline void SetExpectedBucketOwner(const Aws::String& value) { m_expectedBucketOwnerHasBeenSet = true; m_expectedBucketOwner = value; }
+
+    /**
+     * <p>The account id of the expected destination bucket owner. If the destination
+     * bucket is owned by a different account, the request will fail with an HTTP
+     * <code>403 (Access Denied)</code> error.</p>
+     */
+    inline void SetExpectedBucketOwner(Aws::String&& value) { m_expectedBucketOwnerHasBeenSet = true; m_expectedBucketOwner = std::move(value); }
+
+    /**
+     * <p>The account id of the expected destination bucket owner. If the destination
+     * bucket is owned by a different account, the request will fail with an HTTP
+     * <code>403 (Access Denied)</code> error.</p>
+     */
+    inline void SetExpectedBucketOwner(const char* value) { m_expectedBucketOwnerHasBeenSet = true; m_expectedBucketOwner.assign(value); }
+
+    /**
+     * <p>The account id of the expected destination bucket owner. If the destination
+     * bucket is owned by a different account, the request will fail with an HTTP
+     * <code>403 (Access Denied)</code> error.</p>
+     */
+    inline UploadPartCopyRequest& WithExpectedBucketOwner(const Aws::String& value) { SetExpectedBucketOwner(value); return *this;}
+
+    /**
+     * <p>The account id of the expected destination bucket owner. If the destination
+     * bucket is owned by a different account, the request will fail with an HTTP
+     * <code>403 (Access Denied)</code> error.</p>
+     */
+    inline UploadPartCopyRequest& WithExpectedBucketOwner(Aws::String&& value) { SetExpectedBucketOwner(std::move(value)); return *this;}
+
+    /**
+     * <p>The account id of the expected destination bucket owner. If the destination
+     * bucket is owned by a different account, the request will fail with an HTTP
+     * <code>403 (Access Denied)</code> error.</p>
+     */
+    inline UploadPartCopyRequest& WithExpectedBucketOwner(const char* value) { SetExpectedBucketOwner(value); return *this;}
+
+
+    /**
+     * <p>The account id of the expected source bucket owner. If the source bucket is
+     * owned by a different account, the request will fail with an HTTP <code>403
+     * (Access Denied)</code> error.</p>
+     */
+    inline const Aws::String& GetExpectedSourceBucketOwner() const{ return m_expectedSourceBucketOwner; }
+
+    /**
+     * <p>The account id of the expected source bucket owner. If the source bucket is
+     * owned by a different account, the request will fail with an HTTP <code>403
+     * (Access Denied)</code> error.</p>
+     */
+    inline bool ExpectedSourceBucketOwnerHasBeenSet() const { return m_expectedSourceBucketOwnerHasBeenSet; }
+
+    /**
+     * <p>The account id of the expected source bucket owner. If the source bucket is
+     * owned by a different account, the request will fail with an HTTP <code>403
+     * (Access Denied)</code> error.</p>
+     */
+    inline void SetExpectedSourceBucketOwner(const Aws::String& value) { m_expectedSourceBucketOwnerHasBeenSet = true; m_expectedSourceBucketOwner = value; }
+
+    /**
+     * <p>The account id of the expected source bucket owner. If the source bucket is
+     * owned by a different account, the request will fail with an HTTP <code>403
+     * (Access Denied)</code> error.</p>
+     */
+    inline void SetExpectedSourceBucketOwner(Aws::String&& value) { m_expectedSourceBucketOwnerHasBeenSet = true; m_expectedSourceBucketOwner = std::move(value); }
+
+    /**
+     * <p>The account id of the expected source bucket owner. If the source bucket is
+     * owned by a different account, the request will fail with an HTTP <code>403
+     * (Access Denied)</code> error.</p>
+     */
+    inline void SetExpectedSourceBucketOwner(const char* value) { m_expectedSourceBucketOwnerHasBeenSet = true; m_expectedSourceBucketOwner.assign(value); }
+
+    /**
+     * <p>The account id of the expected source bucket owner. If the source bucket is
+     * owned by a different account, the request will fail with an HTTP <code>403
+     * (Access Denied)</code> error.</p>
+     */
+    inline UploadPartCopyRequest& WithExpectedSourceBucketOwner(const Aws::String& value) { SetExpectedSourceBucketOwner(value); return *this;}
+
+    /**
+     * <p>The account id of the expected source bucket owner. If the source bucket is
+     * owned by a different account, the request will fail with an HTTP <code>403
+     * (Access Denied)</code> error.</p>
+     */
+    inline UploadPartCopyRequest& WithExpectedSourceBucketOwner(Aws::String&& value) { SetExpectedSourceBucketOwner(std::move(value)); return *this;}
+
+    /**
+     * <p>The account id of the expected source bucket owner. If the source bucket is
+     * owned by a different account, the request will fail with an HTTP <code>403
+     * (Access Denied)</code> error.</p>
+     */
+    inline UploadPartCopyRequest& WithExpectedSourceBucketOwner(const char* value) { SetExpectedSourceBucketOwner(value); return *this;}
+
+
     
     inline const Aws::Map<Aws::String, Aws::String>& GetCustomizedAccessLogTag() const{ return m_customizedAccessLogTag; }
 
@@ -944,6 +1232,12 @@ namespace Model
     RequestPayer m_requestPayer;
     bool m_requestPayerHasBeenSet;
 
+    Aws::String m_expectedBucketOwner;
+    bool m_expectedBucketOwnerHasBeenSet;
+
+    Aws::String m_expectedSourceBucketOwner;
+    bool m_expectedSourceBucketOwnerHasBeenSet;
+
     Aws::Map<Aws::String, Aws::String> m_customizedAccessLogTag;
     bool m_customizedAccessLogTagHasBeenSet;
   };
